@@ -1,27 +1,20 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-
-# Copyright (c) 2013, 2017 Martin Raspaud
-
-# Author(s):
-
-#   Martin Raspaud <martin.raspaud@smhi.se>
-
+# Copyright (c) 2013-2021 Python-geotiepoints developers
+#
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
-
+#
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
-
+#
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
-
-"""
-"""
+"""Tests for GeoInterpolator."""
 
 import unittest
 
@@ -190,15 +183,3 @@ class TestGeoInterpolator(unittest.TestCase):
                                    TIES_EXP6)
         np.testing.assert_allclose(satint.row_indices,
                                    np.array([0,  2,  7,  9, 10, 12, 17, 19]) / 5.0)
-
-
-def suite():
-    """The suite for GeoInterpolator"""
-    loader = unittest.TestLoader()
-    mysuite = unittest.TestSuite()
-    mysuite.addTest(loader.loadTestsFromTestCase(TestGeoInterpolator))
-
-    return mysuite
-
-if __name__ == '__main__':
-    unittest.main()
